Yandex - velruse.providers.yandex — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »

# Yandex - `velruse.providers.yandex`

The Yandex provider combines authentication with OAuth 2.0 authorization. It requires a Yandex Application to have been created to use.

Yandex Links (English):

- Yandex Services OAuth API

Yandex Links (Russian):

- Register a New Yandex Application
- Yandex Services OAuth API
- Yandex Login + OAuth API

## Settings

`consumer_key`
  Yandex Application ID
`consumer_secret`
  Yandex Application password

## POST Parameters

Complete Example:

    <form action="/velruse/yandex/login" method="post">
        <input type="submit" value="Login with Yandex" />
    </form>

## Pyramid API

Yandex Authentication Views

You may see developer docs at http://api.yandex.com/oauth/

class `YandexAuthenticationComplete`(profile=None, credentials=None, provider_name=None, provider_type=None)

  Bases: `velruse.AuthenticationComplete`

  Yandex auth complete

`includeme`(config)

`add_yandex_login`(config, consumer_key, consumer_secret, login_path='/login/yandex', callback_path='/login/yandex/callback', name='yandex')

  Add a Yandex login provider to the application.

`add_yandex_login_from_settings`(config, prefix='velruse.yandex.')

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »